@@ -7,7 +7,6 @@ from botorch.sampling import MCSampler
 from botorch.utils.transforms import concatenate_pending_points, t_batch_mode_transform
 from torch import Tensor
 
-from xopt.generator import GeneratorOptions
 from xopt.generators.bayesian.bayesian_generator import BayesianGenerator
 from xopt.generators.bayesian.custom_botorch.constrained_acqusition import (
     ConstrainedMCAcquisitionFunction,
@@ -17,15 +16,16 @@ from xopt.generators.bayesian.objectives import (
     create_mc_objective,
 )
 from xopt.generators.bayesian.options import BayesianOptions
+from xopt.utils import format_option_descriptions
 from xopt.vocs import VOCS
 
 
-class BayesianExplorationOptions(GeneratorOptions):
-    pass
-
-
 class BayesianExplorationGenerator(BayesianGenerator):
     alias = "bayesian_exploration"
+    __doc__ = (
+        """Implements Bayeisan Exploration acquisition function"""
+        + f"{format_option_descriptions(BayesianOptions())}"
+    )
 
     def __init__(self, vocs: VOCS, options: BayesianOptions = None):
         """
@@ -59,7 +59,9 @@ class BayesianExplorationGenerator(BayesianGenerator):
         )
 
         cqPV = ConstrainedMCAcquisitionFunction(
-            model, qPV, create_constraint_callables(self.vocs),
+            model,
+            qPV,
+            create_constraint_callables(self.vocs),
         )
 
         return cqPV
