@@ -1,4 +1,5 @@
 import time
+import warnings
 from abc import ABC
 from typing import Callable, Dict, List
 
@@ -8,6 +9,7 @@ from botorch.acquisition import FixedFeatureAcquisitionFunction
 from gpytorch import Module
 from pydantic import BaseModel, create_model, Field, root_validator
 
+from xopt.errors import XoptError
 from xopt.generators.bayesian import BayesianGenerator
 from xopt.generators.bayesian.models.time_dependent import create_time_dependent_model
 from xopt.generators.bayesian.options import AcqOptions, BayesianOptions, ModelOptions
@@ -54,7 +56,7 @@ class TDOptions(BayesianOptions):
 class TimeDependentBayesianGenerator(BayesianGenerator, ABC):
     def __init__(self, vocs: VOCS, options: TDOptions = None):
         options = options or TDOptions()
-        if not isinstance(options, BayesianOptions):
+        if not isinstance(options, TDOptions):
             raise ValueError("options must be a TDOptions object")
 
         super().__init__(vocs, options)
@@ -64,14 +66,20 @@ class TimeDependentBayesianGenerator(BayesianGenerator, ABC):
     def default_options() -> TDOptions:
         return TDOptions()
 
+    def get_input_data(self, data: pd.DataFrame):
+        return torch.tensor(
+            data[self.vocs.variable_names + ["time"]].to_numpy(), **self._tkwargs
+        )
+
     def generate(self, n_candidates: int) -> List[Dict]:
         self.target_prediction_time = time.time() + self.options.acq.added_time
         output = super().generate(n_candidates)
 
         if time.time() > self.target_prediction_time:
-            raise RuntimeWarning(
+            warnings.warn(
                 "target prediction time is in the past! Increase "
-                "added time for accurate results"
+                "added time for accurate results",
+                RuntimeWarning,
             )
         while time.time() < self.target_prediction_time:
             time.sleep(0.001)
@@ -113,3 +121,14 @@ class TimeDependentBayesianGenerator(BayesianGenerator, ABC):
         )
 
         return fixed_acq
+
+    def _get_initial_batch_points(self, bounds):
+        if self.options.optim.use_nearby_initial_points:
+            raise XoptError(
+                "nearby initial points not implemented for "
+                "time dependent optimization"
+            )
+        else:
+            batch_initial_points = None
+            raw_samples = self.options.optim.raw_samples
+        return batch_initial_points, raw_samples
